@@ -1,24 +1,41 @@
+import datetime
 import subprocess
 import sys
 
 from gitgoggles.asciitable import AsciiTable, AsciiCell
 from gitgoggles.git import Repository, TrackingBranch, LocalBranch, PublishedBranch, TrackedBranch
-from gitgoggles.utils import colored
+from gitgoggles.utils import colored, terminal_dimensions
 
 TAG_PREFIX = 'codereview--'
 
 def get_status():
     repo = Repository()
 
-    if repo.configs.get('gitgoggles.fetch', 'True') != 'False':
+    if repo.configs.get('gitgoggles.fetch', 'true') != 'false':
         repo.fetch()
 
     refs = repo.branches(LocalBranch, TrackingBranch, PublishedBranch)
     tags = repo.tags()
 
-    table = AsciiTable([u'Status', u'Branch', u'Review', u'Ahead', u'Behind', u'Pull', u'Push', u'Modified'])
+    BRANCH_WIDTH = repo.configs.get('gitgoggles.table.branch-width')
+    LEFT_PADDING = repo.configs.get('gitgoggles.table.left-padding', 0)
+    RIGHT_PADDING = repo.configs.get('gitgoggles.table.right-padding', 0)
+    HORIZONTAL_RULE = repo.configs.get('gitgoggles.table.horizontal-rule', 'false') != 'false'
 
-    if repo.configs.get('gitgoggles.colors', 'True') == 'False':
+    TERMINAL_ROWS, TERMINAL_COLUMNS = terminal_dimensions()
+
+    table = AsciiTable([
+        AsciiCell('Status'),
+        AsciiCell('Branch', width=BRANCH_WIDTH, resizable=True),
+        AsciiCell('Review', align='right'),
+        AsciiCell('Ahead', align='right'),
+        AsciiCell('Behind', align='right'),
+        AsciiCell('Pull'),
+        AsciiCell('Push'),
+        AsciiCell('Mod', align='right'),
+        ], LEFT_PADDING, RIGHT_PADDING, HORIZONTAL_RULE, TERMINAL_COLUMNS)
+
+    if repo.configs.get('gitgoggles.colors', 'true') == 'false':
         colored.disabled = True
 
     icons = {
@@ -35,7 +52,9 @@ def get_status():
         }
 
     for ref in refs:
-        parent = ref.name in ('staging', 'master',) and 'master' or 'staging'
+        if repo.configs.get('gitgoggles.ignore.%s' % ref.shortname, 'false') == 'true':
+            continue
+
         codereview_tag = "%s%s" % (TAG_PREFIX, ref.shortname)
 
         color = 'red'
@@ -72,22 +91,32 @@ def get_status():
         behind = bool(behind_commits) or None
         tracked = ref.__class__ in (TrackingBranch, LocalBranch, TrackedBranch)
 
-        review_text, review_color = review_commits is not None and (u'%s unreviewed' % review_commits, review and color) or (icons['unknown'], 'yellow',)
+        review_text, review_color = review_commits is not None and (u'%s ahead' % review_commits, review and color) or (icons['unknown'], 'yellow',)
         ahead_text, ahead_color = ahead_commits is not None and (u'%s ahead' % ahead_commits, ahead and color) or (icons['unknown'], 'yellow',)
         behind_text, behind_color = behind_commits is not None and (u'%s behind' % behind_commits, behind and color) or (icons['unknown'], 'yellow',)
 
         pull_text, pull_color = not tracked and (icons['unknown'], 'yellow',) or (pull and (icons['failure'], 'red',) or (icons['success'], 'green',))
         push_text, push_color = not tracked and (icons['unknown'], 'yellow',) or (push and (icons['failure'], 'red',) or (icons['success'], 'green',))
 
+        delta = datetime.date.today() - ref.modified.date()
+        if delta <= datetime.timedelta(days=1):
+            modified_color = 'cyan'
+        elif delta <= datetime.timedelta(days=7):
+            modified_color = 'green'
+        elif delta < datetime.timedelta(days=31):
+            modified_color = 'yellow'
+        else:
+            modified_color = 'red'
+
         table.add_row([
             AsciiCell(status.upper(), color),
-            AsciiCell(ref.name),
-            AsciiCell(review_text, review_color, reverse=review),
-            AsciiCell(ahead_text, ahead_color, reverse=ahead),
-            AsciiCell(behind_text, behind_color, reverse=behind),
-            AsciiCell(pull_text, pull_color),
-            AsciiCell(push_text, push_color),
-            AsciiCell(ref.modified),
+            AsciiCell(ref.name, width=BRANCH_WIDTH, resizable=True),
+            AsciiCell(review_text, review_color, reverse=review, align='right'),
+            AsciiCell(ahead_text, ahead_color, reverse=ahead, align='right'),
+            AsciiCell(behind_text, behind_color, reverse=behind, align='right'),
+            AsciiCell(pull_text, pull_color, align='center'),
+            AsciiCell(push_text, push_color, align='center'),
+            AsciiCell(ref.timedelta, modified_color, align='right'),
             ])
 
     table.render()
@@ -95,25 +124,24 @@ def get_status():
 def complete_review():
     repo = Repository()
 
-    if repo.configs.get('gitgoggles.fetch', 'True') != 'False':
+    if repo.configs.get('gitgoggles.fetch', 'true') != 'false':
         repo.fetch()
 
     branch = repo.branch()
     repo.git('tag', '-a', '%s%s' % (TAG_PREFIX, branch), '-f', '-m', 'creating code review for branch %s' % branch)
     repo.git('push', '--tags')
     print 'Created tag %s%s' % (TAG_PREFIX, branch)
-    repo.git('checkout', 'staging')
-    print 'Switched back to staging branch.'
 
 def start_review():
     repo = Repository()
 
-    if repo.configs.get('gitgoggles.fetch', 'True') != 'False':
+    if repo.configs.get('gitgoggles.fetch', 'true') != 'false':
         repo.fetch()
 
     branch = repo.branch()
     tags = repo.tags()
 
+    # TODO: remove assumption of base branch
     parent = branch in ('staging', 'master',) and 'master' or 'staging'
 
     cr_tag = '%s%s' % (TAG_PREFIX, branch)
@@ -126,7 +154,7 @@ def start_review():
 def update_branches():
     repo = Repository()
 
-    if repo.configs.get('gitgoggles.fetch', 'True') != 'False':
+    if repo.configs.get('gitgoggles.fetch', 'true') != 'false':
         repo.fetch()
 
     branch = repo.branch()
